<?php

/*  Alternate WebshopEngine
(C) 2009-2016 by Alternate Tools
-----------------------------------------------------

File:         class_articlelist.php
Description:  Class cAtricleList definition,
              handling of the article lists

*/

include "class_article.php";

if (!defined("CLASS_ARTICLELIST"))
{
    define ("CLASS_ARTICLELIST", "DEFINED");

    class cArticleList
    {

        var $m_artlFolder;
        var $m_artlIds = array();
        var $m_artlCustFieldCount;

        function __construct()
        {
            $this->Init();
        }

        function cArticleList()  // PHP 4
        {
            $this->__construct();
        }

        function Init()
        {

            $this->m_artlFolder = "";
            $this->m_artlCustFieldCount = 5;  // default
        }

        function SetFolder($artlFolder)
        {
            $this->m_artlFolder = $artlFolder;
        }
        
        function SetCustFieldCount($count)
        {
            $this->m_artlCustFieldCount = $count;
        }

        function SetArticleList($artlArray)
        {
            $this->m_artlIds = $artlArray;
        }

        function GetArticleList()
        {
            if (isset($this->m_artlIds) == true)
                return $this->m_artlIds;
            return array();
        }
        
        function LoadArticleList($filter = 0)
        {
            unset($this->m_artlIds);
            if (is_dir($this->m_artlFolder) == false)
                return false;
                
            $rDir = dir($this->m_artlFolder);
            $strEntry = "";
            $fileName = "";
            $artArticle = new cArticle;
            $artArticle->SetFolder($this->m_artlFolder);

            while (false !== ($strEntry = $rDir->read()))
            {
                if (substr($strEntry, -4 ) == '.art')
                {
                    $fileName = substr($strEntry, 0, strlen($strEntry) - 4);
                    if ($filter == 0)
                        $this->m_artlIds[] = $fileName;
                    else
                    {
                        if ($artArticle->LoadArticleFromId($fileName) == true)
                        {
                            $addMe = false;
                            switch($filter)
                            {
                                case 1:   // unlocked
                                   if ($artArticle->IsLocked() == false)
                                       $addMe = true;
                                break;
                                case 2:   // locked
                                   if ($artArticle->IsLocked() == true)
                                       $addMe = true;
                                break;
                                case 3:   // unlocked and available
                                   if ($artArticle->IsLocked() == false && $artArticle->IsArticleSoldOut() == false)
                                       $addMe = true;
                                break;
                            }
                            if ($addMe == true)
                                $this->m_artlIds[] = $fileName;
                        }
                    }
                }
            }
            return true;
        }

        function LoadArticleListFromCatId($catId, $filter = 0)
        {
            $this->LoadArticleList($filter);
            $tmpArray = array();
            $artArticle = new cArticle;
            $artArticle->SetFolder($this->m_artlFolder);
            if (isset($this->m_artlIds) == false)
                $this->m_artlIds = array();
            for ($i = 0; $i < count($this->m_artlIds); $i ++)
            {
                if ($artArticle->LoadArticleFromId($this->m_artlIds[$i]) == true)
                {
                    if ($artArticle->GetCategoryId() == $catId)
                        $tmpArray[] = $artArticle->GetId();
                }
            }
            unset($this->m_artlIds);
            $this->m_artlIds = $tmpArray;
        }

        function SortArticleList($sort = -1)
        {
            if (isset($this->m_artlIds) == false)
                return;
                
            $artArticle = new cArticle;
            $artArticle->SetFolder($this->m_artlFolder);
            $preArray = array();
            if ($sort == 0 || $sort < -6 || $sort > 6) // undefined, then default it
                $sort = -1;
            foreach ($this->m_artlIds as $value)
            {
                $artArticle->LoadArticleFromId($value);
                if ($sort == -1 || $sort == 1)  // Date or Id
                    $preArray[] = $artArticle->GetId() . '-|-' . $artArticle->GetId();
                else if ($sort == -2 || $sort == 2)  // Name
                    $preArray[] = $artArticle->GetName() . '-|-' . $artArticle->GetId();
                else if ($sort == -3 || $sort == 3)  // Price
                    $preArray[] = sprintf("%010.2f", $artArticle->GetPrice()) . '-|-' . $artArticle->GetId();
                else if ($sort == -4 || $sort == 4)  // Category
                    $preArray[] = $artArticle->GetCategoryId() . '-|-' . $artArticle->GetId();
                else if ($sort == -5 || $sort == 5)  // Popularity
                    $preArray[] = sprintf("%010.2f", $artArticle->GetViewCount()) . '-|-' . $artArticle->GetId();
                else  // Most ordered
                    $preArray[] = sprintf("%010.2f", $artArticle->GetOrderCount()) . '-|-' . $artArticle->GetId();
            }
            if ($sort > 0)  // ascending
                sort($preArray);
            else
                rsort($preArray);
            unset($this->m_artlIds);
            foreach ($preArray as $value)
            {
                $tmpArray = explode('-|-', $value);
                $this->m_artlIds[] = $tmpArray[1];
            }
        }

        function LoadSearchActiceArticleList($searchStr)
        {
            unset($this->m_artlIds);
            $rDir = dir($this->m_artlFolder);
            $strEntry = "";
            $fileName = "";
            $artArticle = new cArticle;
            $artArticle->SetFolder($this->m_artlFolder);

            while (false !== ($strEntry = $rDir->read()))
            {
                if (substr($strEntry, -4 ) == '.art')
                {
                    $fileName = substr($strEntry, 0, strlen($strEntry) - 4);
                    if ($artArticle->LoadArticleFromId($fileName) == true)
                    {
                        if ($artArticle->IsLocked() == false)
                           if (stristr($artArticle->GetTags(), $searchStr) != "" ||
                               stristr($artArticle->GetDescription(), $searchStr) != "" ||
                               stristr($artArticle->GetName(), $searchStr) != "")
                            $this->m_artlIds[] = $fileName;
                    }
                }
            }
        }
        
        function GetTotalArticles()
        {
            $this->LoadArticleList();
            if (isset($this->m_artlIds) == false)
                return 0;
            return count ($this->m_artlIds);
        }

        function GetLockedArticles()
        {
            $this->LoadArticleList(2);
            if (isset($this->m_artlIds) == false)
                return 0;
            return count ($this->m_artlIds);
        }

        function GetMostViewedArticle()
        {
            $artArticle = new cArticle;
            $artArticle->SetFolder($this->m_artlFolder);
            $this->LoadArticleList();
            if (isset($this->m_artlIds) == false)
                return false;
            $mostViewed = array();
            $mostViewed[] = -1;
            $mostViewed[] = 0;
            $mostViewed[] = 0;
            for ($i = 0; $i < count($this->m_artlIds); $i ++)
            {
                $artArticle->LoadArticleFromId($this->m_artlIds[$i]);
                if ($mostViewed[0] == -1 || $artArticle->GetViewCount() > $mostViewed[0])
                {
                    $mostViewed[0] = $artArticle->GetViewCount();
                    $mostViewed[1] = $artArticle->GetId();
                }
                $mostViewed[2] += $artArticle->GetViewCount();
            }
            return $mostViewed;
        }

        function GetMostOrderedArticle()
        {
            $artArticle = new cArticle;
            $artArticle->SetFolder($this->m_artlFolder);
            $this->LoadArticleList();
            if (isset($this->m_artlIds) == false)
                return false;
            $mostOrdered = array();
            $mostOrdered[] = -1;
            $mostOrdered[] = 0;
            $mostOrdered[] = 0;
            for ($i = 0; $i < count($this->m_artlIds); $i ++)
            {
                $artArticle->LoadArticleFromId($this->m_artlIds[$i]);
                if ($mostOrdered[0] == -1 || $artArticle->GetOrderCount() > $mostOrdered[0])
                {
                    $mostOrdered[0] = $artArticle->GetOrderCount();
                    $mostOrdered[1] = $artArticle->GetId();
                }
                $mostOrdered[2] += $artArticle->GetOrderCount();
            }
            return $mostOrdered;
        }

        function ResetArticleStatistics()
        {
            $artArticle = new cArticle;
            $artArticle->SetFolder($this->m_artlFolder);
            $artArticle->SetCustFieldCount($this->m_artlCustFieldCount);
            $this->LoadArticleList();
            if (isset($this->m_artlIds) == false)
                return false;
            for ($i = 0; $i < count($this->m_artlIds); $i ++)
            {
                $artArticle->LoadArticleFromId($this->m_artlIds[$i]);
                $artArticle->ResetCounters();
            }
        }

    }
}
?>